@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 10389 2017-10-22 05:43:34Z Lavender $
+# $Id: models.py 11686 2019-08-21 04:00:34Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,15 +12,15 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-10-22 13:43:34 +0800 (Sun, 22 Oct 2017) $
-# $Revision: 10389 $
+# $Date: 2019-08-21 13:00:34 +0900 (週三, 21 八月 2019) $
+# $Revision: 11686 $
 
 from django.db import models
 from jsonfield import JSONField
 
 class Email(models.Model):
     email = models.EmailField()
-    fromUrl = models.URLField()
+    fromUrl = models.URLField(max_length=400)
     date = models.DateTimeField(
         auto_now_add=True)
 
